@@ -18,23 +18,23 @@ namespace HighFive {
 /// \brief Utility class to disable HDF5 stack printing inside a scope.
 ///
 class SilenceHDF5 {
-public:
-    inline SilenceHDF5(bool enable=true)
-        : _client_data(nullptr)
-    {
+  public:
+    inline SilenceHDF5(bool enable = true)
+        : _client_data(nullptr) {
         H5Eget_auto2(H5E_DEFAULT, &_func, &_client_data);
-        if (enable) H5Eset_auto2(H5E_DEFAULT, NULL, NULL);
+        if (enable)
+            H5Eset_auto2(H5E_DEFAULT, NULL, NULL);
     }
 
     inline ~SilenceHDF5() {
         H5Eset_auto2(H5E_DEFAULT, _func, _client_data);
     }
 
-private:
+  private:
     H5E_auto2_t _func;
     void* _client_data;
 };
 
 }  // namespace HighFive
 
-#endif // H5UTIL_HPP
+#endif  // H5UTIL_HPP
