@@ -34,6 +34,10 @@ void bind_immutable_module(py::module& m) {
         .def(py::init<const std::string&, unsigned int>(),
              "filename"_a,
              "options"_a = morphio::enums::Option::NO_MODIFIER)
+        .def(py::init<const std::string&, const std::string&, unsigned int>(),
+             "filename"_a,
+             "extension"_a,
+             "options"_a = morphio::enums::Option::NO_MODIFIER)
         .def(py::init<morphio::mut::Morphology&>())
         .def(py::init([](py::object arg, unsigned int options) {
                  return std::make_unique<morphio::Morphology>(py::str(arg), options);
