@@ -1,5 +1,5 @@
 #pragma once
-#include <stdexcept>
+#include <stdexcept>  // std::runtime_error
 
 namespace morphio {
 
