@@ -1,7 +1,10 @@
 #pragma once
 
-#include <morphio/mut/morphology.h>
-#include <morphio/types.h>
+#include <string>
+#include <vector>
+
+#include <morphio/mut/morphology.h>  // mut::Morphology
+#include <morphio/properties.h>      // Property
 
 namespace morphio {
 namespace mut {
@@ -11,7 +14,7 @@ class DendriticSpine: public Morphology
 {
   public:
     DendriticSpine();
-    DendriticSpine(const std::string& source);
+    explicit DendriticSpine(const std::string& source);
 
     std::vector<Property::DendriticSpine::PostSynapticDensity>& postSynapticDensity() noexcept;
     const std::vector<Property::DendriticSpine::PostSynapticDensity>& postSynapticDensity() const
