@@ -1,16 +1,11 @@
 #pragma once
 
-#include <memory>  // std::shared_ptr
-#include <string>  // std::string
-#include <vector>  // std::vector
+#include <utility>  // std::pair
 
-#include <gsl/gsl>
 #include <morphio/enums.h>
 #include <morphio/exceptions.h>
 #include <morphio/vector_types.h>
 
-
-/** @namespace morphio Blue Brain File IO classes */
 namespace morphio {
 
 using namespace enums;
@@ -28,7 +23,7 @@ class Soma;
 
 namespace Property {
 struct Properties;
-}
+}  // namespace Property
 
 /** Functionality for vasculature (blood)  **/
 namespace vasculature {
@@ -55,10 +50,4 @@ class Soma;
 
 using SectionRange = std::pair<size_t, size_t>;
 
-// A tuple (file format (std::string), major version, minor version)
-using MorphologyVersion = std::tuple<std::string, uint32_t, uint32_t>;
-
-template <typename T>
-using range = gsl::span<T>;
-
 }  // namespace morphio
