@@ -10,9 +10,10 @@ GlialCell::GlialCell()
 
 GlialCell::GlialCell(const std::string& source)
     : Morphology(source) {
-    if (_cellProperties->_cellFamily != CellFamily::GLIA)
+    if (_cellProperties->_cellFamily != CellFamily::GLIA) {
         throw(RawDataError("File: " + source +
                            " is not a GlialCell file. It should be a H5 file the cell type GLIA."));
+    }
 }
 
 }  // namespace mut
