@@ -4,7 +4,9 @@
 namespace morphio {
 namespace readers {
 namespace asc {
-Property::Properties load(const std::string& uri, unsigned int options);
+Property::Properties load(const std::string& path,
+                          const std::string& contents,
+                          unsigned int options);
 }  // namespace asc
 }  // namespace readers
 }  // namespace morphio
