@@ -6,9 +6,9 @@
 namespace morphio {
 namespace readers {
 namespace swc {
-Property::Properties load(const std::string& uri, unsigned int options);
+Property::Properties load(const std::string& path,
+                          const std::string& contents,
+                          unsigned int options);
 }  // namespace swc
-
 }  // namespace readers
-
 }  // namespace morphio
