@@ -1,6 +1,8 @@
 #include <morphio/errorMessages.h>
 #include <morphio/types.h>
 
+#include "point_utils.h"
+
 
 namespace morphio {
 
@@ -10,23 +12,19 @@ std::string valueToString(const std::array<T, N>& a) {
     std::copy(a.begin(), a.end(), std::ostream_iterator<T>(oss, ", "));
     return oss.str();
 }
+
 template <typename T>
 std::string valueToString(const T a) {
     return std::to_string(a);
 }
 
-template <typename ContainerDiameters, typename ContainerPoints>
-floatType _somaSurface(const SomaType type,
-                       const ContainerDiameters& diameters,
-                       const ContainerPoints& points) {
+inline floatType _somaSurface(const SomaType type,
+                              const range<const floatType>& diameters,
+                              const range<const Point>& points) {
     size_t size = points.size();
 
     switch (type) {
-    case SOMA_SINGLE_POINT: {
-        floatType radius = diameters[0] / 2;
-        return 4 * morphio::PI * radius * radius;
-    }
-
+    case SOMA_SINGLE_POINT:
     case SOMA_NEUROMORPHO_THREE_POINT_CYLINDERS: {
         floatType radius = diameters[0] / 2;
         return 4 * morphio::PI * radius * radius;
@@ -38,7 +36,7 @@ floatType _somaSurface(const SomaType type,
         for (unsigned int i = 0; i < size - 1; ++i) {
             floatType r0 = static_cast<morphio::floatType>(diameters[i]) * floatType{0.5};
             floatType r1 = static_cast<morphio::floatType>(diameters[i + 1]) * floatType{0.5};
-            floatType h2 = distance(points[i], points[i + 1]);
+            floatType h2 = euclidean_distance(points[i], points[i + 1]);
             auto s = morphio::PI * (r0 + r1) * std::sqrt((r0 - r1) * (r0 - r1) + h2 * h2);
             surface += s;
         }
@@ -54,6 +52,7 @@ floatType _somaSurface(const SomaType type,
     }
     }
 }
+
 template <typename T>
 void _appendVector(std::vector<T>& to, const std::vector<T>& from, int offset) {
     to.insert(to.end(), from.begin() + offset, from.end());
