@@ -2,6 +2,7 @@
 #include <morphio/soma.h>
 #include <morphio/vector_types.h>
 
+#include "point_utils.h"
 #include "shared_utils.hpp"
 
 namespace morphio {
@@ -29,7 +30,7 @@ floatType Soma::volume() const {
 }
 
 floatType Soma::surface() const {
-    return _somaSurface<range<const floatType>, range<const Point>>(type(), diameters(), points());
+    return _somaSurface(type(), diameters(), points());
 }
 
 floatType Soma::maxDistance() const {
