@@ -5,6 +5,7 @@
 #include <morphio/properties.h>
 #include <morphio/vasc/properties.h>
 
+#include "../point_utils.h"
 #include "../shared_utils.hpp"
 
 namespace morphio {
@@ -130,12 +131,12 @@ bool compare(const morphio::range<const morphio::Point>& vec1,
     }
 
     for (size_t i = 0; i < vec1.size(); ++i) {
-        if (std::fabs(distance(vec1[i], vec2[i])) > morphio::epsilon) {
+        if (std::fabs(euclidean_distance(vec1[i], vec2[i])) > morphio::epsilon) {
             if (verbose_) {
                 printError(Warning::UNDEFINED, "Error comparing " + name + ", elements differ:");
                 printError(Warning::UNDEFINED,
                            valueToString(vec1[i]) + " <--> " + valueToString(vec2[i]));
-                printError(Warning::UNDEFINED, valueToString(vec2[i] - vec1[i]));
+                printError(Warning::UNDEFINED, valueToString(subtract(vec2[i], vec1[i])));
             }
             return false;
         }
