@@ -2,6 +2,8 @@
 
 #include <morphio/vasc/section.h>
 
+#include "../point_utils.h"
+
 namespace morphio {
 namespace vasculature {
 
@@ -103,7 +105,7 @@ floatType Section::length() const {
     }
 
     size_t last = points_.size() - 1;
-    return distance(points_[0], points_[last]);
+    return euclidean_distance(points_[0], points_[last]);
 }
 
 range<const Point> Section::points() const {
